@@ -28,7 +28,7 @@ as.bugs.array2 <- function(sims.array, model.file=NULL, program="jags",
   root.long <- character(n.parameters)
   indexes.long <- vector(n.parameters, mode = "list")
   for (i in 1:n.parameters) {
-    temp <- R2WinBUGS:::decode.parameter.name(parameter.names[i])
+    temp <- .decode.parameter.name(parameter.names[i])
     root.long[i] <- temp$root
     indexes.long[[i]] <- temp$indexes
   }
@@ -77,7 +77,7 @@ as.bugs.array2 <- function(sims.array, model.file=NULL, program="jags",
   }
   # ----
   dimnames(sims) <- list(NULL, parameter.names)
-  summary <- R2WinBUGS:::monitor(sims.array, n.chains, keep.all = TRUE)
+  summary <- monitor(sims.array, n.chains, keep.all = TRUE)
   last.values <- as.list(numeric(n.chains))
   
   for(nn in 1:length(n.indexes.short)){
